"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const chai = require("chai");
const install_1 = require("../standalone/install");
const pact_environment_1 = require("./pact-environment");
const pact_standalone_1 = require("./pact-standalone");
const expect = chai.expect;
const basePath = pact_environment_1.default.cwd;
describe('Pact Standalone', function () {
    this.timeout(600000);
    let pact;
    after(() => install_1.default());
    it('should return an object with cwd, file and fullPath properties that is platform specific', () => {
        pact = pact_standalone_1.standalone();
        expect(pact).to.be.an('object');
        expect(pact.cwd).to.be.ok;
        expect(pact.brokerPath).to.contain('pact-broker');
        expect(pact.brokerFullPath).to.contain('pact-broker');
        expect(pact.mockServicePath).to.contain('pact-mock-service');
        expect(pact.mockServiceFullPath).to.contain('pact-mock-service');
        expect(pact.stubPath).to.contain('pact-stub-service');
        expect(pact.stubFullPath).to.contain('pact-stub-service');
        expect(pact.verifierPath).to.contain('pact-provider-verifier');
        expect(pact.verifierFullPath).to.contain('pact-provider-verifier');
        expect(pact.pactPath).to.contain('pact');
        expect(pact.pactFullPath).to.contain('pact');
    });
    it("should return the base directory of the project with 'cwd' (where the package.json file is)", () => {
        expect(fs.existsSync(path.resolve(pact.cwd, 'package.json'))).to.be.true;
    });
    describe('Check if OS specific files are there', () => {
        describe('OSX', () => {
            before(() => install_1.default('darwin'));
            beforeEach(() => (pact = pact_standalone_1.standalone('darwin')));
            it('broker relative path', () => {
                expect(fs.existsSync(path.resolve(basePath, pact.brokerPath))).to.be
                    .true;
            });
            it('broker full path', () => {
                expect(fs.existsSync(pact.brokerFullPath)).to.be.true;
            });
            it('mock service relative path', () => {
                expect(fs.existsSync(path.resolve(basePath, pact.mockServicePath))).to
                    .be.true;
            });
            it('mock service full path', () => {
                expect(fs.existsSync(pact.mockServiceFullPath)).to.be.true;
            });
            it('stub relative path', () => {
                expect(fs.existsSync(path.resolve(basePath, pact.stubPath))).to.be.true;
            });
            it('stub full path', () => {
                expect(fs.existsSync(pact.stubFullPath)).to.be.true;
            });
            it('provider verifier relative path', () => {
                expect(fs.existsSync(path.resolve(basePath, pact.verifierPath))).to.be
                    .true;
            });
            it('provider verifier full path', () => {
                expect(fs.existsSync(pact.verifierFullPath)).to.be.true;
            });
            it('pact relative path', () => {
                expect(fs.existsSync(path.resolve(basePath, pact.pactPath))).to.be.true;
            });
            it('pact full path', () => {
                expect(fs.existsSync(pact.pactFullPath)).to.be.true;
            });
        });
        describe('Linux ia32', () => {
            before(() => install_1.default('linux', 'ia32'));
            beforeEach(() => (pact = pact_standalone_1.standalone('linux', 'ia32')));
            it('broker relative path', () => {
                expect(fs.existsSync(path.resolve(basePath, pact.brokerPath))).to.be
                    .true;
            });
            it('broker full path', () => {
                expect(fs.existsSync(pact.brokerFullPath)).to.be.true;
            });
            it('mock service relative path', () => {
                expect(fs.existsSync(path.resolve(basePath, pact.mockServicePath))).to
                    .be.true;
            });
            it('mock service full path', () => {
                expect(fs.existsSync(pact.mockServiceFullPath)).to.be.true;
            });
            it('stub relative path', () => {
                expect(fs.existsSync(path.resolve(basePath, pact.stubPath))).to.be.true;
            });
            it('stub full path', () => {
                expect(fs.existsSync(pact.stubFullPath)).to.be.true;
            });
            it('provider verifier relative path', () => {
                expect(fs.existsSync(path.resolve(basePath, pact.verifierPath))).to.be
                    .true;
            });
            it('provider verifier full path', () => {
                expect(fs.existsSync(pact.verifierFullPath)).to.be.true;
            });
            it('pact relative path', () => {
                expect(fs.existsSync(path.resolve(basePath, pact.pactPath))).to.be.true;
            });
            it('pact full path', () => {
                expect(fs.existsSync(pact.pactFullPath)).to.be.true;
            });
        });
        describe('Linux X64', () => {
            before(() => install_1.default('linux', 'x64'));
            beforeEach(() => (pact = pact_standalone_1.standalone('linux', 'x64')));
            it('broker relative path', () => {
                expect(fs.existsSync(path.resolve(basePath, pact.brokerPath))).to.be
                    .true;
            });
            it('broker full path', () => {
                expect(fs.existsSync(pact.brokerFullPath)).to.be.true;
            });
            it('mock service relative path', () => {
                expect(fs.existsSync(path.resolve(basePath, pact.mockServicePath))).to
                    .be.true;
            });
            it('mock service full path', () => {
                expect(fs.existsSync(pact.mockServiceFullPath)).to.be.true;
            });
            it('stub relative path', () => {
                expect(fs.existsSync(path.resolve(basePath, pact.stubPath))).to.be.true;
            });
            it('stub full path', () => {
                expect(fs.existsSync(pact.stubFullPath)).to.be.true;
            });
            it('provider verifier relative path', () => {
                expect(fs.existsSync(path.resolve(basePath, pact.verifierPath))).to.be
                    .true;
            });
            it('provider verifier full path', () => {
                expect(fs.existsSync(pact.verifierFullPath)).to.be.true;
            });
            it('pact relative path', () => {
                expect(fs.existsSync(path.resolve(basePath, pact.pactPath))).to.be.true;
            });
            it('pact full path', () => {
                expect(fs.existsSync(pact.pactFullPath)).to.be.true;
            });
        });
        describe('Windows', () => {
            before(() => install_1.default('win32'));
            beforeEach(() => (pact = pact_standalone_1.standalone('win32')));
            it("should add '.bat' to the end of the binary names", () => {
                expect(pact.brokerPath).to.contain('pact-broker.bat');
                expect(pact.brokerFullPath).to.contain('pact-broker.bat');
                expect(pact.mockServicePath).to.contain('pact-mock-service.bat');
                expect(pact.mockServiceFullPath).to.contain('pact-mock-service.bat');
                expect(pact.stubPath).to.contain('pact-stub-service.bat');
                expect(pact.stubFullPath).to.contain('pact-stub-service.bat');
                expect(pact.verifierPath).to.contain('pact-provider-verifier.bat');
                expect(pact.verifierFullPath).to.contain('pact-provider-verifier.bat');
                expect(pact.pactPath).to.contain('pact.bat');
                expect(pact.pactFullPath).to.contain('pact.bat');
            });
            it('broker relative path', () => {
                expect(fs.existsSync(path.resolve(basePath, pact.brokerPath))).to.be
                    .true;
            });
            it('broker full path', () => {
                expect(fs.existsSync(pact.brokerFullPath)).to.be.true;
            });
            it('mock service relative path', () => {
                expect(fs.existsSync(path.resolve(basePath, pact.mockServicePath))).to
                    .be.true;
            });
            it('mock service full path', () => {
                expect(fs.existsSync(pact.mockServiceFullPath)).to.be.true;
            });
            it('stub relative path', () => {
                expect(fs.existsSync(path.resolve(basePath, pact.stubPath))).to.be.true;
            });
            it('stub full path', () => {
                expect(fs.existsSync(pact.stubFullPath)).to.be.true;
            });
            it('provider verifier relative path', () => {
                expect(fs.existsSync(path.resolve(basePath, pact.verifierPath))).to.be
                    .true;
            });
            it('provider verifier full path', () => {
                expect(fs.existsSync(pact.verifierFullPath)).to.be.true;
            });
            it('pact relative path', () => {
                expect(fs.existsSync(path.resolve(basePath, pact.pactPath))).to.be.true;
            });
            it('pact full path', () => {
                expect(fs.existsSync(pact.pactFullPath)).to.be.true;
            });
        });
    });
});
//# sourceMappingURL=pact-standalone.spec.js.map