"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const express = require("express");
const q = require("q");
const data_utils_1 = require("./data-utils");
const cors = require("cors");
const bodyParser = require("body-parser");
exports.default = (port) => {
    const server = express();
    server.use(cors());
    server.use(bodyParser.json());
    server.use(bodyParser.urlencoded({
        extended: true,
    }));
    let stateData = '';
    server.get('/', data_utils_1.returnJson({ greeting: 'Hello' }));
    server.get('/fail', data_utils_1.returnJson({ greeting: 'Oh noes!' }));
    server.get('/provider-states', data_utils_1.returnJson({
        me: ['There is a greeting'],
        anotherclient: ['There is a greeting'],
    }));
    server.post('/provider-state', (req, res) => {
        stateData = 'State data!';
        return res.json({
            greeting: stateData,
        });
    });
    server.get('/somestate', (req, res) => {
        return res.json({
            greeting: stateData,
        });
    });
    server.post('/', (req, res) => {
        return res.json({
            greeting: `Hello ${req.body.name}`,
        });
    });
    server.get('/contract/:name', (req, res) => {
        const fileName = req.params.name;
        res.sendFile(fileName, {
            root: __dirname,
            dotfiles: 'deny',
            headers: {
                'x-timestamp': Date.now(),
                'x-sent': true,
            },
        }, err => {
            if (err) {
                console.log(err);
                res.status(500).end();
            }
            else {
                console.log('Sent:', fileName);
            }
        });
    });
    server.post('/pacts/provider/:provider/consumer/:consumer/pact-version/:version/verification-results', data_utils_1.returnJsonFile('./data/get-provider_they-consumer_me-latest.json'));
    server.get('/pacts/provider/they/consumer/me/latest', data_utils_1.auth, data_utils_1.returnJsonFile('./data/get-provider_they-consumer_me-latest.json'));
    server.get('/pacts/provider/they/consumer/anotherclient/latest', data_utils_1.auth, data_utils_1.returnJsonFile('./data/get-provider_they-consumer_anotherclient-latest.json'));
    server.get('/noauth/pacts/provider/they/consumer/me/latest', data_utils_1.returnJsonFile('./data/get-noauth-provider_they-consumer_me-latest.json'));
    server.get('/noauth/pacts/provider/they/consumer/anotherclient/latest', data_utils_1.returnJsonFile('./data/get-noauth-provider_they-consumer_anotherclient-latest.json'));
    const deferred = q.defer();
    let s = server.listen(port, () => deferred.resolve());
    return deferred.promise.then(() => s);
};
//# sourceMappingURL=provider-mock.js.map