"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai = require("chai");
const chaiAsPromised = require("chai-as-promised");
const fs = require("fs");
const message_1 = require("../src/message");
const path = require("path");
const logger_1 = require("../src/logger");
chai.use(chaiAsPromised);
const rimraf = require("rimraf");
const expect = chai.expect;
describe('Message Integration Spec', () => {
    const pactDir = process && process.mainModule
        ? `${path.dirname(process.mainModule.filename)}/pacts`
        : '/tmp/pacts';
    const contractFile = `${pactDir}/consumer-provider.json`;
    const validJSON = `{ "description": "a test mesage", "content": { "name": "Mary" } }`;
    context('when given a successful contract', () => {
        before(() => {
            try {
                if (fs.statSync(contractFile)) {
                    rimraf(pactDir, () => logger_1.default.debug('removed existing pacts'));
                }
            }
            catch (e) { }
        });
        it('should return a successful promise', done => {
            const message = message_1.default({
                consumer: 'consumer',
                provider: 'provider',
                dir: `${pactDir}`,
                content: validJSON,
            });
            const promise = message.createMessage();
            promise.then(() => {
                expect(fs.statSync(contractFile).isFile()).to.eql(true);
                done();
            });
        });
    });
});
//# sourceMappingURL=message.integration.spec.js.map